# 2024.10.0

**Released on October 21th, 2024**

[Documentation for this release](https://cotainr.readthedocs.org/en/2024.10.0/)

A major release mainly focused on synchronizing with the LUMI 09/2024 upgrade.

## New features

- Create an example of using cotainr for building a container with a mpi4py/MPICH conda/pip environment for use on LUMI-C. It includes simple "MPI hello world" examples of how to correctly use such a container on LUMI. [PR#50](https://github.com/DeiC-HPC/cotainr/pull/50)
- Cotainr now features the standard `--version` CLI command, [PR#59](https://github.com/DeiC-HPC/cotainr/pull/59)

## Bug fixes

- Flush the input buffer before prompting the user for permissions, [#61](https://github.com/DeiC-HPC/cotainr/pull/61)
- Fix when base image files have restricted permissions, [PR#49](https://github.com/DeiC-HPC/cotainr/pull/49)
- Minor documentation fixes, [#54](https://github.com/DeiC-HPC/cotainr/pull/54), [#60](https://github.com/DeiC-HPC/cotainr/pull/60), [#69](https://github.com/DeiC-HPC/cotainr/pull/69)

## Maintenance updates

- The LUMI PyTorch example has been updated to match the state of LUMI as of 09/2024, [PR#73](https://github.com/DeiC-HPC/cotainr/pull/73).
- Update documentation to reflect cotainr residing in the CrayEnv software stack on LUMI, [#63](https://github.com/DeiC-HPC/cotainr/pull/63)
- Upgrade the Github Continuous Integration [PR#71](https://github.com/DeiC-HPC/cotainr/pull/71), [PR#72](https://github.com/DeiC-HPC/cotainr/pull/72)
- Change from linting from using `black` to `ruff` [PR#56](https://github.com/DeiC-HPC/cotainr/pull/56)
